from compas.utilities import color_to_colordict

import compas_rhino


__all__ = ['PathArtist']


class PathArtist(object):

    def draw_path(self, path):
        """Draw a path from one vertex to another as a polyline of edges.

        Parameters
        ----------
        path : list
            A list of ordered vertices forming a vaild path on the network.

        Notes
        -----

        Examples
        --------
        >>>

        """
        pass


# ==============================================================================
# Main
# ==============================================================================

if __name__ == "__main__":
    pass
